@@ -39,7 +39,6 @@ from humanize import naturalsize
 from loguru import logger
 from ruamel.yaml import YAML
 
-
 # Configuration access to Cyber Range endpoint
 CORE_API_URL = "http://127.0.0.1:5000"
 # Expect a path to CA certs (see:
@@ -52,7 +51,6 @@ CLIENT_CERT_PATH = None
 # https://requests.readthedocs.io/en/master/user/advanced/)
 CLIENT_KEY_PATH = None
 
-
 # Simulation status mapping
 map_status = {
     "CREATED": 1,
@@ -61,7 +59,7 @@ map_status = {
     "STARTING": 4,
     "PROVISIONING": 5,
     "RUNNING": 6,
-    "SCENARIO_PLAYING": 7,
+    "USER_ACTIVITY_PLAYING": 7,
     "STOPPING": 8,
     "DESTROYED": 9,
     "CLONING": 10,
@@ -133,7 +131,8 @@ def _simulation_execute_operation(
     operation: str,
     id_simulation: int,
     operation_status: str,
-    optional_param: Optional[Any] = None,
+    optional_param1: Optional[Any] = None,
+    optional_param2: Optional[Any] = None,
 ) -> str:
     """Generic method to launch API operation on a target simulation."""
 
@@ -145,8 +144,10 @@ def _simulation_execute_operation(
 
     # Build URI
     uri = f"/simulation/{id_simulation}/{operation}"
-    if optional_param is not None:
-        uri = f"{uri}/{str(optional_param)}"
+    if optional_param1 is not None:
+        uri = f"{uri}/{str(optional_param1)}"
+    if optional_param2 is not None:
+        uri = f"{uri}/{str(optional_param2)}"
 
     # Request URI
     result = _get(uri)
@@ -301,11 +302,41 @@ def _simu_create_add_implicit_dns_parameter(topology: Any) -> None:
             node["dns"] = list(dict.fromkeys(node["dns"]))
 
 
-def _simu_create_validate_resources_path(resources_path: str) -> None:
-    if os.path.exists(resources_path) is not True:
-        raise Exception(
-            'The provided resources path does not exist: "{}"'.format(resources_path)
-        )
+def __validate_resources_path(
+    resources_path: str, raise_exception: bool = True
+) -> bool:
+    # Exists ?
+    if not os.path.exists(resources_path):
+        if raise_exception:
+            raise FileNotFoundError(
+                f'The provided resources path does not exist: "{resources_path}"'
+            )
+        return False
+    # Directory ?
+    if not os.path.isdir(resources_path):
+        if raise_exception:
+            raise NotADirectoryError(
+                f'The provided resources path is not a directory: "{resources_path}"'
+            )
+        return False
+    # Empty ?
+    files = os.listdir(resources_path)
+    if len(files) == 0:
+        if raise_exception:
+            raise OSError(
+                f'The provided resources path is an empty directory: "{resources_path}"'
+            )
+        return False
+    # Readable ?
+    for file_name in files:
+        file_path = os.path.join(resources_path, file_name)
+        if not os.access(file_path, os.R_OK):
+            if raise_exception:
+                raise PermissionError(
+                    f'The provided resources path contains unreadable files: "{resources_path}"'
+                )
+            return False
+    return True
 
 
 # -------------------------------------------------------------------------- #
@@ -400,7 +431,8 @@ def create_simulation_from_topology(
     # Add a default resources directory if it exists.
     # If the topology is "path/to/topo.yaml", the default resources directory is "path/to/resources".
     default_resources_path = os.path.join(os.path.dirname(topology_file), "resources")
-    if os.path.exists(default_resources_path) and os.path.isdir(default_resources_path):
+    default_resources_path = os.path.normpath(default_resources_path)
+    if __validate_resources_path(default_resources_path, False):
         if default_resources_path not in topology_resources_paths:
             topology_resources_paths.append(default_resources_path)
 
@@ -410,7 +442,7 @@ def create_simulation_from_topology(
 
     for resource in topology_resources_paths:
         # Validate resources path
-        _simu_create_validate_resources_path(resource)
+        __validate_resources_path(resource)  # raise an exception if invalid
         # take the absolute path
         simulation_dict["resources_paths"].append(os.path.abspath(resource))
 
@@ -469,7 +501,7 @@ nodes:
         yaml_content += """
   - &host_machine
     type: host_machine
-    name: "host_machine"
+    name: "host"
 """
 
     if add_internet:
@@ -483,11 +515,11 @@ nodes:
 
   - &switch_internet
     type: switch
-    name: "switch_internet"
+    name: "switchInternet"
 
   - &physical_gateway
     type: physical_gateway
-    name: "physical_gateway"
+    name: "physicalGateway"
 """
     else:
         yaml_content += """
@@ -1544,7 +1576,9 @@ def fetch_topologies() -> Any:
 ###
 
 
-def start_simulation(id_simulation: int, use_install_time: bool = False) -> None:
+def start_simulation(
+    id_simulation: int, use_install_time: bool = False, timeout: int = 300
+) -> None:
     """Start the simulation, with current time (by default) or time where the VM was created
     (use_install_time=True).
 
@@ -1560,7 +1594,11 @@ def start_simulation(id_simulation: int, use_install_time: bool = False) -> None
 
     # Initiate the simulation
     _simulation_execute_operation(
-        "start", id_simulation, "STARTING", optional_param=use_install_time
+        "start",
+        id_simulation,
+        "STARTING",
+        optional_param1=use_install_time,
+        optional_param2=timeout,
     )
 
 
@@ -1684,12 +1722,12 @@ def net_start_capture(id_simulation: int, iface: str, pcap: bool, filter: str) -
     :param id_simulation: The id of the simulation.
     :param iface: Interface where the traffic is mirrored to.
     :param pcap: A boolean indicating if the capture should be saved on disk in a pcap file (to be included in dataset)
-    :param filter: 
+    :param filter:
 
     :type id_simulation: :class:`int`, ex : 1
     :type iface: :class:`str`, ex : dummy0
-    :type pcap: :class:`bool` 
-    :type filter: :class:`str` 
+    :type pcap: :class:`bool`
+    :type filter: :class:`str`
 
     """
 
