@@ -50,7 +50,7 @@ import cr_api_client
 import cr_api_client.core_api as core_api
 import cr_api_client.provisioning_api as provisioning_api
 import cr_api_client.redteam_api as redteam_api
-import cr_api_client.scenario_api as scenario_api
+import cr_api_client.user_activity_api as user_activity_api
 import cr_api_client.publish_api as publish_api
 
 # Initialize colorama
@@ -65,11 +65,18 @@ else:
 #
 # 'status' related functions
 #
-def status_handler(args: Any) -> None:
+def status_handler(args: Any) -> None:  # noqa: C901
     """Get platform status."""
 
+    exit_code = 0
+
     client_version = cr_api_client.__version__
-    logger.info("[+] cr_api_client version: {}".format(client_version))
+    client_fullversion = cr_api_client.__fullversion__
+    logger.info(
+        f"[+] cr_api_client version: {client_version} ({client_fullversion})".format(
+            client_version
+        )
+    )
 
     logger.info("[+] Platform status")
 
@@ -79,6 +86,7 @@ def status_handler(args: Any) -> None:
     try:
         core_api_version = core_api.get_version()
     except requests.exceptions.ConnectionError:
+        exit_code = 1
         logger.warning(
             "    [-] API status: " + colored("not running !", "white", "on_red")
         )
@@ -86,6 +94,7 @@ def status_handler(args: Any) -> None:
         logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
         logger.info("    [+] version: {}".format(core_api_version))
         if client_version != core_api_version:
+            exit_code = 1
             logger.info(
                 "    [-] "
                 + colored(
@@ -101,6 +110,7 @@ def status_handler(args: Any) -> None:
     try:
         status = core_api.virtclient_status()
     except Exception:
+        exit_code = 1
         logger.warning(
             "    [-] compute status: " + colored("not running !", "white", "on_red")
         )
@@ -108,24 +118,26 @@ def status_handler(args: Any) -> None:
         logger.info("    [+] compute status: " + colored("OK", "grey", "on_green"))
         logger.info("    [+] available slots: {}".format(status["nb_slots"]))
 
-    # Scenario API
-    logger.info("  [+] Scenario API")
-    logger.info("    [+] address: {}".format(scenario_api.SCENARIO_API_URL))
+    # User activity API
+    logger.info("  [+] User activity API")
+    logger.info("    [+] address: {}".format(user_activity_api.USER_ACTIVITY_API_URL))
     try:
-        scenario_api_version = scenario_api.get_version()
+        user_activity_api_version = user_activity_api.get_version()
     except requests.exceptions.ConnectionError:
+        exit_code = 1
         logger.warning(
             "    [-] API status: " + colored("not running !", "white", "on_red")
         )
     else:
         logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
-        logger.info("    [+] version: {}".format(scenario_api_version))
-        if client_version != scenario_api_version:
+        logger.info("    [+] version: {}".format(user_activity_api_version))
+        if client_version != user_activity_api_version:
+            exit_code = 1
             logger.info(
                 "    [-] "
                 + colored(
-                    "warning: Scenario API version ({}) mismatchs with cr_api_client version ({})".format(
-                        scenario_api_version, client_version
+                    "warning: User activity API version ({}) mismatchs with cr_api_client version ({})".format(
+                        user_activity_api_version, client_version
                     ),
                     "white",
                     "on_red",
@@ -138,6 +150,7 @@ def status_handler(args: Any) -> None:
     try:
         provisioning_api_version = provisioning_api.get_version()
     except requests.exceptions.ConnectionError:
+        exit_code = 1
         logger.warning(
             "    [-] API status: " + colored("not running !", "white", "on_red")
         )
@@ -145,6 +158,7 @@ def status_handler(args: Any) -> None:
         logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
         logger.info("    [+] version: {}".format(provisioning_api_version))
         if client_version != provisioning_api_version:
+            exit_code = 1
             logger.info(
                 "    [-] "
                 + colored(
@@ -162,6 +176,7 @@ def status_handler(args: Any) -> None:
     try:
         redteam_api_version = redteam_api.get_version()
     except requests.exceptions.ConnectionError:
+        exit_code = 1
         logger.warning(
             "    [-] API status: " + colored("not running !", "white", "on_red")
         )
@@ -169,6 +184,7 @@ def status_handler(args: Any) -> None:
         logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
         logger.info("    [+] version: {}".format(redteam_api_version))
         if client_version != redteam_api_version:
+            exit_code = 1
             logger.info(
                 "    [-] "
                 + colored(
@@ -180,30 +196,34 @@ def status_handler(args: Any) -> None:
                 )
             )
 
-    # # Testing frontend
-    # logger.info("  [+] Frontend")
-    # logger.info(
-    #     "    [+] Address: {}:{}".format(
-    #         cyber_range_conf.frontend["listen_host"],
-    #         cyber_range_conf.frontend["listen_port"],
-    #     )
-    # )
-    # try:
-    #     result = requests.get(
-    #         "http://{}:{}".format(
-    #             cyber_range_conf.frontend["listen_host"],
-    #             cyber_range_conf.frontend["listen_port"],
-    #         )
-    #     )
-    #     if result.status_code != 200:
-    #         raise Exception("Error detected in frontend response")
-    # except requests.exceptions.ConnectionError:
-    #     logger.info("    [+] Status: not running !")
-    # except Exception:
-    #     logger.info("    [+] Status: not working properly !")
-    #     return
-    # else:
-    #     logger.info("    [+] Status: OK")
+    # Redteam API
+    logger.info("  [+] Dataset API")
+    logger.info("    [+] address: {}".format(publish_api.PUBLISH_API_URL))
+    try:
+        dataset_api_version = publish_api.get_version()
+    except requests.exceptions.ConnectionError:
+        exit_code = 1
+        logger.warning(
+            "    [-] API status: " + colored("not running !", "white", "on_red")
+        )
+    else:
+        logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
+        logger.info("    [+] version: {}".format(dataset_api_version))
+        if client_version != dataset_api_version:
+            exit_code = 1
+            logger.info(
+                "    [-] "
+                + colored(
+                    "warning: Dataset API version ({}) mismatchs with cr_api_client version ({})".format(
+                        dataset_api_version, client_version
+                    ),
+                    "white",
+                    "on_red",
+                )
+            )
+
+    if exit_code != 0:
+        sys.exit(exit_code)
 
 
 #
@@ -584,16 +604,16 @@ def provisioning_stop_handler(args: Any) -> None:
     # Parameters
     task_id = args.task_id
 
-    print("[+] Stopping provisioning task with id '{}'".format(task_id))
+    logger.info("[+] Stopping provisioning task with id '{}'".format(task_id))
 
     try:
         provisioning_api.provisioning_stop(task_id)
-        print("[+] Stopping done.")
+        logger.info("[+] Stopping done.")
 
     except Exception as e:
         error_msg = str(e)
         error_msg = error_msg.replace("\\n", "\n")
-        print(f"[-] Error while stopping provisioning: {error_msg}")
+        logger.error(f"[-] Error while stopping provisioning: {error_msg}")
         sys.exit(1)
 
 
@@ -606,73 +626,109 @@ def provisioning_status_handler(args: Any) -> None:
     # Parameters
     task_id = args.task_id
 
-    print("[+] Provisioning task status with id '{}'".format(task_id))
+    logger.info("[+] Provisioning task status with id '{}'".format(task_id))
 
     try:
         result = provisioning_api.provisioning_status(task_id)
         status = result["status"]
         if status is None:
-            print(
+            logger.info(
                 f"[+] Status unknown, this task id doesn't exist or is finished: {task_id}"
             )
         else:
-            print(f"[+] Status: {status}")
+            logger.info(f"[+] Status: {status}")
 
     except Exception as e:
         error_msg = str(e)
         error_msg = error_msg.replace("\\n", "\n")
-        print(f"[-] Error while provisioning status: {error_msg}")
+        logger.info(f"[-] Error while provisioning status: {error_msg}")
         sys.exit(1)
 
 
 #
-# 'scenario_play' simulation
+# 'provisioning_report' related functions
 #
-def scenario_play_handler(args: Any) -> None:
-    """Play scenario on targeted simulation."""
-    # Parameters
-    id_simulation = args.id_simulation
-    scenario_path = args.scenario_path
-    file_results = args.scenario_file_results
-    debug_mode = args.scenario_debug_mode
-    speed = args.scenario_speed
-    record_video = args.scenario_record_video
-    write_logfile = args.scenario_write_logfile
+def provisioning_report_handler(args: Any) -> None:
+    """Report of all currently running provisioning agents"""
 
-    logger.info(
-        "[+] Playing scenario '{}' on simulation id '{}'".format(
-            scenario_path, id_simulation
-        )
-    )
+    logger.info("[+] Provisioning report: ")
 
     try:
-        scenario_api.scenario_play(
+        result = provisioning_api.provisioning_report()
+        for task_id in result:
+            logger.info("  [+] --------------------------------------")
+            logger.info(f"  [+] {task_id}:")
+            logger.info("  [+] --------------------------------------")
+            logger.info(f"{result[task_id]}")
+
+    except Exception as e:
+        error_msg = str(e)
+        error_msg = error_msg.replace("\\n", "\n")
+        logger.info(f"[-] Error while retrieving provisioning report: {error_msg}")
+        sys.exit(1)
+
+
+#
+# 'user_activity_play' simulation
+#
+def user_activity_play_handler(args: Any) -> None:
+    """Play user_activity on targeted simulation."""
+    # Parameters
+    id_simulation = args.id_simulation
+    user_activity_path = args.user_activity_path
+    file_results = args.user_activity_file_results
+    debug_mode = args.user_activity_debug_mode
+    speed = args.user_activity_speed
+    record_video = args.user_activity_record_video
+    write_logfile = args.user_activity_write_logfile
+    wait = not args.user_activity_nowait
+
+    try:
+        user_activity_api.user_activity_play(
             id_simulation=id_simulation,
-            scenario_path=scenario_path,
+            user_activity_path=user_activity_path,
             debug_mode=debug_mode,
+            wait=wait,
             speed=speed,
             record_video=record_video,
             write_logfile=write_logfile,
-            scenario_file_results=file_results,
+            user_activity_file_results=file_results,
         )
     except Exception as e:
-        logger.info(f"Error when playing scenario: '{e}'")
+        logger.info(f"Error when playing user_activity: '{e}'")
         sys.exit(1)
 
 
 #
-# 'scenario_status' simulation
+# 'user_activity_status' simulation
 #
-def scenario_status_handler(args: Any) -> None:
-    """Get scenario status on targeted simulation."""
+def user_activity_status_handler(args: Any) -> None:
+    """Get user_activity status on targeted simulation."""
     # Parameters
     id_simulation = args.id_simulation
+    task_id = args.task_id
 
-    logger.info("[+] Get scenario status on simulation id '{}'".format(id_simulation))
-    status = scenario_api.scenario_status(id_simulation)
+    logger.info("[+] Get user_activity status for task '{}'".format(task_id))
+    status = user_activity_api.user_activity_status(id_simulation, task_id)
     logger.info("  [+] Current status: {}".format(status["status"]))
 
 
+#
+# 'all_activities_status' simulation
+#
+def all_activities_status_handler(args: Any) -> None:
+    """Get user_activity status on targeted simulation."""
+    # Parameters
+    id_simulation = args.id_simulation
+    logger.info("[+] Get user_activity status for all user activities.")
+    status = user_activity_api.all_activities_status(id_simulation)
+    for task_id in status:
+        logger.info("   [+] ID: '{}', STATUS: '{}'".format(task_id, status[task_id][0]))
+        logger.info("       [+] Impacted machines:")
+        for machine in status[task_id][1]:
+            logger.info("           [+] '{}'".format(machine))
+
+
 #
 # 'simu_run' simulation
 #
@@ -684,6 +740,7 @@ def simu_run_handler(args: Any) -> None:
     iface = args.iface
     pcap = args.pcap
     filter = args.filter
+    timeout = args.timeout
 
     # Compute elpased time
     t1 = time.time()
@@ -706,7 +763,9 @@ def simu_run_handler(args: Any) -> None:
                     errorMessage = "Filter defined without --net_pcap option"
                     raise ValueError(errorMessage)
 
-                core_api.start_simulation(id_simulation, use_install_time)
+                core_api.start_simulation(
+                    id_simulation, use_install_time, timeout=timeout
+                )
                 core_api.net_start_capture(id_simulation, iface, pcap, filter)
             except Exception as e:
                 logger.info(f"An error occurred while activating tap: '{e}'")
@@ -714,7 +773,7 @@ def simu_run_handler(args: Any) -> None:
             else:
                 logger.info("[+] Redirect network traffic to the tap interface")
         else:
-            core_api.start_simulation(id_simulation, use_install_time)
+            core_api.start_simulation(id_simulation, use_install_time, timeout=timeout)
     except Exception as e:
         logger.info(f"Error when starting simulation: '{e}'")
         sys.exit(1)
@@ -1132,7 +1191,7 @@ def node_stats_handler(args: Any) -> None:
 
     stats = json.loads(response)
     logger.debug("Statistics on simulation gathered")
-    print(json.dumps(stats))
+    logger.info(json.dumps(stats))
 
 
 #
@@ -1471,10 +1530,10 @@ def set_core_api_url(core_api_url: str) -> str:
     return core_api_url
 
 
-def set_scenario_api_url(scenario_api_url: str) -> str:
-    logger.info("  [+] Using scenario API URL: {}".format(scenario_api_url))
-    scenario_api.SCENARIO_API_URL = scenario_api_url
-    return scenario_api_url
+def set_user_activity_api_url(user_activity_api_url: str) -> str:
+    logger.info("  [+] Using user_activity API URL: {}".format(user_activity_api_url))
+    user_activity_api.USER_ACTIVITY_API_URL = user_activity_api_url
+    return user_activity_api_url
 
 
 def set_provisioning_api_url(provisioning_api_url: str) -> str:
@@ -1483,6 +1542,12 @@ def set_provisioning_api_url(provisioning_api_url: str) -> str:
     return provisioning_api_url
 
 
+def set_publish_api_url(publish_api_url: str) -> str:
+    logger.info("  [+] Using publish API URL: {}".format(publish_api_url))
+    publish_api.PUBLISH_API_URL = publish_api_url
+    return publish_api_url
+
+
 def set_redteam_api_url(redteam_api_url: str) -> str:
     logger.info("  [+] Using redteam API URL: {}".format(redteam_api_url))
     redteam_api.REDTEAM_API_URL = redteam_api_url
@@ -1492,8 +1557,9 @@ def set_redteam_api_url(redteam_api_url: str) -> str:
 def set_cacert(cacert: str) -> str:
     logger.info("  [+] Using CA certs path: {}".format(cacert))
     core_api.CA_CERT_PATH = cacert
-    scenario_api.CA_CERT_PATH = cacert
+    user_activity_api.CA_CERT_PATH = cacert
     provisioning_api.CA_CERT_PATH = cacert
+    publish_api.CA_CERT_PATH = cacert
     redteam_api.CA_CERT_PATH = cacert
     return cacert
 
@@ -1501,8 +1567,9 @@ def set_cacert(cacert: str) -> str:
 def set_cert(cert: str) -> str:
     logger.info("  [+] Using client cert path: {}".format(cert))
     core_api.CLIENT_CERT_PATH = cert
-    scenario_api.CLIENT_CERT_PATH = cert
+    user_activity_api.CLIENT_CERT_PATH = cert
     provisioning_api.CLIENT_CERT_PATH = cert
+    publish_api.CLIENT_CERT_PATH = cert
     redteam_api.CLIENT_CERT_PATH = cert
     return cert
 
@@ -1510,8 +1577,9 @@ def set_cert(cert: str) -> str:
 def set_key(key: str) -> str:
     logger.info("  [+] Using client key path: {}".format(key))
     core_api.CLIENT_KEY_PATH = key
-    scenario_api.CLIENT_KEY_PATH = key
+    user_activity_api.CLIENT_KEY_PATH = key
     provisioning_api.CLIENT_KEY_PATH = key
+    publish_api.CLIENT_KEY_PATH = key
     redteam_api.CLIENT_KEY_PATH = key
     return key
 
@@ -1519,17 +1587,8 @@ def set_key(key: str) -> str:
 def main() -> None:
     parser = argparse.ArgumentParser()
 
-    # Manage options passed in config file
+    # Config file argument
     parser.add_argument("--config", help="Configuration file")
-    args, left_argv = parser.parse_known_args()
-    if args.config:
-        configfile_path = args.config
-        logger.info(f"  [+] Using config file: {configfile_path}")
-        if not os.path.exists(configfile_path):
-            raise Exception(f"Path '{configfile_path}' does not exist.")
-        config = configparser.SafeConfigParser()
-        fp = open(configfile_path)
-        config.readfp(fp)
 
     # Common debug argument
     parser.add_argument(
@@ -1541,42 +1600,81 @@ def main() -> None:
     )
 
     # Common options to access remote API
+    options_by_dest = dict()
+
+    option_name = "--core-url"
+    dest_name = "core_api_url"
+    options_by_dest[dest_name] = option_name
     parser.add_argument(
-        "--core-url",
-        dest="core_api_url",
+        option_name,
+        dest=dest_name,
         type=set_core_api_url,
         help="Set core API URL (default: '{}')".format(core_api.CORE_API_URL),
     )
+
+    option_name = "--user-activity-url"
+    dest_name = "user_activity_api_url"
+    options_by_dest[dest_name] = option_name
     parser.add_argument(
-        "--scenario-url",
-        dest="scenario_api_url",
-        type=set_scenario_api_url,
-        help="Set scenario API URL (default: '{}')".format(
-            scenario_api.SCENARIO_API_URL
+        option_name,
+        dest=dest_name,
+        type=set_user_activity_api_url,
+        help="Set user_activity API URL (default: '{}')".format(
+            user_activity_api.USER_ACTIVITY_API_URL
         ),
     )
+
+    option_name = "--provisioning-url"
+    dest_name = "provisioning_api_url"
+    options_by_dest[dest_name] = option_name
     parser.add_argument(
-        "--provisioning-url",
-        dest="provisioning_api_url",
+        option_name,
+        dest=dest_name,
         type=set_provisioning_api_url,
         help="Set provisioning API URL (default: '{}')".format(
             provisioning_api.PROVISIONING_API_URL
         ),
     )
+
+    option_name = "--redteam-url"
+    dest_name = "redteam_api_url"
+    options_by_dest[dest_name] = option_name
     parser.add_argument(
-        "--redteam-url",
-        dest="redteam_api_url",
+        option_name,
+        dest=dest_name,
         type=set_redteam_api_url,
         help="Set redteam API URL (default: '{}')".format(redteam_api.REDTEAM_API_URL),
     )
+
+    option_name = "--publish-url"
+    dest_name = "publish_api_url"
+    options_by_dest[dest_name] = option_name
     parser.add_argument(
-        "--cacert", dest="cacert", type=set_cacert, help="Set path to CA certs"
+        option_name,
+        dest=dest_name,
+        type=set_publish_api_url,
+        help="Set publish API URL (default: '{}')".format(publish_api.PUBLISH_API_URL),
     )
+
+    option_name = "--cacert"
+    dest_name = "cacert"
+    options_by_dest[dest_name] = option_name
     parser.add_argument(
-        "--cert", dest="cert", type=set_cert, help="Set path to client cert"
+        option_name, dest=dest_name, type=set_cacert, help="Set path to CA certs"
     )
+
+    option_name = "--cert"
+    dest_name = "cert"
+    options_by_dest[dest_name] = option_name
     parser.add_argument(
-        "--key", dest="key", type=set_key, help="Set path to client key"
+        option_name, dest=dest_name, type=set_cert, help="Set path to client cert"
+    )
+
+    option_name = "--key"
+    dest_name = "key"
+    options_by_dest[dest_name] = option_name
+    parser.add_argument(
+        option_name, dest=dest_name, type=set_key, help="Set path to client key"
     )
 
     subparsers = parser.add_subparsers()
@@ -1701,6 +1799,15 @@ def main() -> None:
     parser_simu_run.add_argument(
         "-f", type=str, dest="filter", default="", help="Tcpdump filter"
     )
+    parser_simu_run.add_argument(
+        "--timeout",
+        action="store",
+        type=int,
+        required=False,
+        dest="timeout",
+        default=300,
+        help=f"Timeout for starting simulation (default to %(default)s seconds)",
+    )
 
     # 'simu_status' simulation command
     parser_simu_status = subparsers.add_parser(
@@ -2170,6 +2277,12 @@ def main() -> None:
         "task_id", type=str, help="The provisioning task id"
     )
 
+    # 'provisioning_report' command
+    parser_provisioning_report = subparsers.add_parser(
+        "provisioning_report", help="Prints report of all active provisioning tasks"
+    )
+    parser_provisioning_report.set_defaults(func=provisioning_report_handler)
+
     # 'provisioning_inventory' command
     parser_provisioning_inventory = subparsers.add_parser(
         "provisioning_inventory",
@@ -2201,71 +2314,97 @@ def main() -> None:
     )
 
     # -----------------------
-    # --- Scenario options
+    # --- User activity options
     # -----------------------
 
-    # 'scenario_play' command
-    parser_scenario_play = subparsers.add_parser(
-        "scenario_play", help="Play scenario on a simulation"
+    # 'user_activity_play' command
+    parser_user_activity_play = subparsers.add_parser(
+        "user_activity_play", help="Play user_activity on a simulation"
     )
-    parser_scenario_play.set_defaults(func=scenario_play_handler)
-    parser_scenario_play.add_argument(
+    parser_user_activity_play.set_defaults(func=user_activity_play_handler)
+    parser_user_activity_play.add_argument(
         "id_simulation", type=int, help="The simulation id"
     )
-    parser_scenario_play.add_argument(
+    parser_user_activity_play.add_argument(
         "-i",
         action="store",
         nargs="?",
         required=True,
-        dest="scenario_path",
-        help="Path of the scenario to play",
+        dest="user_activity_path",
+        help="Path of the user_activity to play",
     )
 
-    parser_scenario_play.add_argument(
+    parser_user_activity_play.add_argument(
         "-o",
         action="store",
         required=False,
-        dest="scenario_file_results",
-        help="Absolute name of scenario results (JSON format)",
+        dest="user_activity_file_results",
+        help="Absolute name of user_activity results (JSON format)",
     )
 
-    parser_scenario_play.add_argument(
+    parser_user_activity_play.add_argument(
         "-d",
         action="store",
         required=False,
-        dest="scenario_debug_mode",
+        dest="user_activity_debug_mode",
         default="off",
         help="Debug mode ('off', 'on', 'full')",
     )
-    parser_scenario_play.add_argument(
+    parser_user_activity_play.add_argument(
         "-t",
         action="store",
         required=False,
-        dest="scenario_speed",
+        dest="user_activity_speed",
         default="normal",
-        help="scenario speed ('slow', 'normal', 'fast')",
+        help="user_activity speed ('slow', 'normal', 'fast')",
     )
-    parser_scenario_play.add_argument(
+    parser_user_activity_play.add_argument(
         "--record-video",
         action="store_true",
         default=False,
-        dest="scenario_record_video",
+        dest="user_activity_record_video",
         help="record video of the play. For debug purpose only",
     )
-    parser_scenario_play.add_argument(
+    parser_user_activity_play.add_argument(
         "--write-logfile",
         action="store_true",
         default=False,
-        dest="scenario_write_logfile",
+        dest="user_activity_write_logfile",
         help="write logging messages of the play in a file. For debug purpose only",
     )
-
-    # 'scenario_status' command
-    parser_scenario_status = subparsers.add_parser(
-        "scenario_status", help="Get scenario status on a simulation"
+    parser_user_activity_play.add_argument(
+        "--no-wait",
+        action="store_true",
+        default=False,
+        dest="user_activity_nowait",
+        help="Don't wait for the task to be done",
     )
-    parser_scenario_status.set_defaults(func=scenario_status_handler)
-    parser_scenario_status.add_argument(
+
+    # 'user_activity_status' command
+    parser_user_activity_status = subparsers.add_parser(
+        "user_activity_status", help="Get user_activity status on a simulation"
+    )
+    parser_user_activity_status.set_defaults(func=user_activity_status_handler)
+    parser_user_activity_status.add_argument(
+        "id_simulation", type=int, help="The simulation id"
+    )
+
+    parser_user_activity_status.add_argument(
+        "-id",
+        action="store",
+        nargs="?",
+        required=True,
+        dest="task_id",
+        help="Task ID to get status from",
+    )
+
+    # 'all_activities_status' command
+    parser_all_activities_status = subparsers.add_parser(
+        "all_activities_status",
+        help="Get user_activity statuses for all user activities on a targeted simulation",
+    )
+    parser_all_activities_status.set_defaults(func=all_activities_status_handler)
+    parser_all_activities_status.add_argument(
         "id_simulation", type=int, help="The simulation id"
     )
 
@@ -2337,10 +2476,38 @@ def main() -> None:
         parser.print_help(sys.stderr)
         sys.exit(0)
 
-    # Handle parameter written in config file
+    args, left_argv = parser.parse_known_args()
+
+    # Manage options passed in config file
+    # Note that if an option is defined both in command line and config file,
+    # the command line value takes precedences
     if args.config:
+        # Load config file options
+        configfile_path = args.config
+        logger.info(f"  [+] Using config file: {configfile_path}")
+        if not os.path.exists(configfile_path):
+            raise Exception(f"Path '{configfile_path}' does not exist.")
+        config = configparser.SafeConfigParser()
+        fp = open(configfile_path)
+        config.readfp(fp)
+
+        # find options defined in command line
+        args_in_command_line = list()
+        args_as_dict = vars(args)
+        for key, value in args_as_dict.items():
+            if key in options_by_dest and value is not None:
+                args_in_command_line.append(options_by_dest[key])
+
         for k, v in config.items("DEFAULT"):
-            parser.parse_args([str(k), str(v)], args)
+            # if the argument is also in the command line, it overwrites the one present in the config file
+            if k in args_in_command_line:
+                logger.info(
+                    f"  [+] Skipping '{option_name}' option defined in config file (already defined in command line)"
+                )
+            else:
+                parser.parse_args([str(k), str(v)], args)
+
+        fp.close()
 
     # Parse remaining args from command line (overriding potential config file
     # parameters)
