@@ -526,12 +526,13 @@ def provisioning_wait_until_complete(
 def __wait_for_the_operation_to_start(task_id: str) -> bool:
 
     running = False
-    timeout = 10
+    timeout = 5
     start_time = time.time()
     while not (running or (time.time() - start_time) > timeout):
         result = _post("/provisioning/status_provisioning", data={"task_id": task_id})
         result.raise_for_status()
         result = result.json()
+        print(result)
         running = result["status"] == "RUNNING"
         time.sleep(1)
 
@@ -575,3 +576,14 @@ def __handle_wait(
             success = False
 
     return success
+
+
+def provisioning_report():
+    """Get ansible report from backend"""
+
+    result = _post("/provisioning/report_provisioning", data={})
+
+    if result.status_code != 200:
+        _handle_error(result, "Cannot get report from provisioning task")
+
+    return result.json()
