@@ -385,7 +385,7 @@ def attack_knowledge() -> str:
     """
     Get the attack knowledge (attack hosts and sessions).
 
-    :return: Attack hosts and sessins.
+    :return: Attack hosts and sessions.
 
     >>> from cr_api_client import redteam_api
     >>> redteam_api.reset_redteam()
