@@ -10,7 +10,7 @@
 from pathlib import Path
 from typing import List
 
-import yaml
+from ruamel.yaml import YAML
 from pydantic import BaseModel
 from pydantic import validator
 
@@ -35,7 +35,8 @@ class Topology(BaseModel):
 
     @staticmethod
     def from_yaml_string(value: str) -> "Topology":
-        return Topology(**yaml.safe_load(value))
+        loader = YAML(typ="rt")
+        return Topology(**loader.load(value))
 
     @staticmethod
     def from_yaml_file(path: Path) -> "Topology":
@@ -43,4 +44,5 @@ class Topology(BaseModel):
 
     def to_yaml_string(self) -> str:
         # TODO: add custom yaml representers
+        yaml = YAML(typ="rt")
         return yaml.dump(self.dict())
